# FullCalendar

A full-sized drag & drop event calendar (jQuery plugin).

- [Project website and demos](http://fullcalendar.io/)
- [Documentation](http://fullcalendar.io/docs/)
- [Support](http://fullcalendar.io/support/)
- [Contributing](CONTRIBUTING.md)
- [Changelog](CHANGELOG.md)
- [License](LICENSE.txt)